@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..2\n"; }
+BEGIN { $| = 1; print "1..3\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Parse::Passwd;
 $loaded = 1;
@@ -24,3 +24,8 @@ my $p = Parse::Passwd->file;
 warn Dumper($p);
 
 print "ok 2\n";
+
+print join '--', Parse::Passwd->fields;
+print "\n";
+
+print "ok 3\n";
